@@ -1,17 +1,17 @@
 from abc import ABC, abstractmethod
-from typing import Optional
+from typing import Optional, Tuple
 
 
 class Backend(ABC):
 
     @abstractmethod
-    def process(self, key: str, interval_ms: int, limit: int) -> tuple[Optional[str], dict]:
+    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
         pass
 
 
 class CountingBackend(Backend):
 
-    def process(self, key: str, interval_ms: int, limit: int) -> tuple[Optional[str], dict]:
+    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
         requests_made = self.get_and_increment(key, interval_ms, limit)
         meta = {
             'key': key,
