@@ -17,7 +17,7 @@ def create_ratelimit_decorator(engine: LimiterEngine, error_handler: LimiterErro
             @wraps(func)
             async def wrapper(request: Request, *args, **kwargs):
                 limit_result = await engine.limit(config, request)
-                print(limit_result)
+                # print(limit_result)
 
                 if limit_result.limit_applied:
                     if error_handler:
