@@ -14,7 +14,7 @@ def create_ratelimit_depends(engine: LimiterEngine, error_handler: LimiterErrorH
 
         async def call(request: Request):
             limit_result = await engine.limit(config, request)
-            print(limit_result)
+            # print(limit_result)
 
             if limit_result.limit_applied:
                 if error_handler:
